==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/PrincipalDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * PrincipalDefinition properties of Basic Rule
 * @property attributes A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
 * @property clientids A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
 * @property usernames A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
 */
public data class PrincipalDefinitionArgs(
    public val attributes: Output<List<Map<String, String>>>? = null,
    public val clientids: Output<List<String>>? = null,
    public val usernames: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs.builder()
            .attributes(
                attributes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.map({ args0 ->
                            args0.key.to(args0.value)
                        }).toMap()
                    })
                }),
            )
            .clientids(clientids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .usernames(usernames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PrincipalDefinitionArgs].
 */
@PulumiTagMarker
public class PrincipalDefinitionArgsBuilder internal constructor() {
    private var attributes: Output<List<Map<String, String>>>? = null

    private var clientids: Output<List<String>>? = null

    private var usernames: Output<List<String>>? = null

    /**
     * @param value A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("elmhembtwfnlnwkr")
    public suspend fun attributes(`value`: Output<List<Map<String, String>>>) {
        this.attributes = value
    }

    @JvmName("iabtsfptwqiffnet")
    public suspend fun attributes(vararg values: Output<Map<String, String>>) {
        this.attributes = Output.all(values.asList())
    }

    /**
     * @param values A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("kuidjidwlgxeaguw")
    public suspend fun attributes(values: List<Output<Map<String, String>>>) {
        this.attributes = Output.all(values)
    }

    /**
     * @param value A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("lnbckftqtihuryri")
    public suspend fun clientids(`value`: Output<List<String>>) {
        this.clientids = value
    }

    @JvmName("fqffhfrprmsuxbib")
    public suspend fun clientids(vararg values: Output<String>) {
        this.clientids = Output.all(values.asList())
    }

    /**
     * @param values A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("lxhxdhqbqtwlvtms")
    public suspend fun clientids(values: List<Output<String>>) {
        this.clientids = Output.all(values)
    }

    /**
     * @param value A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("xxdpmkaqxkqyhgde")
    public suspend fun usernames(`value`: Output<List<String>>) {
        this.usernames = value
    }

    @JvmName("bkhpqubcgkrpnvjj")
    public suspend fun usernames(vararg values: Output<String>) {
        this.usernames = Output.all(values.asList())
    }

    /**
     * @param values A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("cjwxwexseooeureh")
    public suspend fun usernames(values: List<Output<String>>) {
        this.usernames = Output.all(values)
    }

    /**
     * @param value A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("ulrfdvbarubofhkv")
    public suspend fun attributes(`value`: List<Map<String, String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param values A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("flbgsmhrifkijwbw")
    public suspend fun attributes(vararg values: Map<String, String>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param value A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("nsrftfugqxqjeohv")
    public suspend fun clientids(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientids = mapped
    }

    /**
     * @param values A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("rwhbadvvnxfrceow")
    public suspend fun clientids(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientids = mapped
    }

    /**
     * @param value A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("lgeovofexjgdrquv")
    public suspend fun usernames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    /**
     * @param values A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("kayddtvprkqlxysc")
    public suspend fun usernames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    internal fun build(): PrincipalDefinitionArgs = PrincipalDefinitionArgs(
        attributes = attributes,
        clientids = clientids,
        usernames = usernames,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/PrincipalDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * PrincipalDefinition properties of Basic Rule
 * @property attributes A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
 * @property clientids A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
 * @property usernames A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
 */
public data class PrincipalDefinitionArgs(
    public val attributes: Output<List<Map<String, String>>>? = null,
    public val clientids: Output<List<String>>? = null,
    public val usernames: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.PrincipalDefinitionArgs.builder()
            .attributes(
                attributes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.map({ args0 ->
                            args0.key.to(args0.value)
                        }).toMap()
                    })
                }),
            )
            .clientids(clientids?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .usernames(usernames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [PrincipalDefinitionArgs].
 */
@PulumiTagMarker
public class PrincipalDefinitionArgsBuilder internal constructor() {
    private var attributes: Output<List<Map<String, String>>>? = null

    private var clientids: Output<List<String>>? = null

    private var usernames: Output<List<String>>? = null

    /**
     * @param value A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("gldqpsryexrtnern")
    public suspend fun attributes(`value`: Output<List<Map<String, String>>>) {
        this.attributes = value
    }

    @JvmName("vdtvqkwkmaaqhqeu")
    public suspend fun attributes(vararg values: Output<Map<String, String>>) {
        this.attributes = Output.all(values.asList())
    }

    /**
     * @param values A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("tebuoeomkbafvixr")
    public suspend fun attributes(values: List<Output<Map<String, String>>>) {
        this.attributes = Output.all(values)
    }

    /**
     * @param value A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("mysvuvhfeawlybem")
    public suspend fun clientids(`value`: Output<List<String>>) {
        this.clientids = value
    }

    @JvmName("fwmiipogmxqujqqc")
    public suspend fun clientids(vararg values: Output<String>) {
        this.clientids = Output.all(values.asList())
    }

    /**
     * @param values A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("rdwapgrbkuqsafqk")
    public suspend fun clientids(values: List<Output<String>>) {
        this.clientids = Output.all(values)
    }

    /**
     * @param value A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("nxpjttucpynudpwx")
    public suspend fun usernames(`value`: Output<List<String>>) {
        this.usernames = value
    }

    @JvmName("aoylesrwponavsgm")
    public suspend fun usernames(vararg values: Output<String>) {
        this.usernames = Output.all(values.asList())
    }

    /**
     * @param values A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("dlsygiuoqxakcmob")
    public suspend fun usernames(values: List<Output<String>>) {
        this.usernames = Output.all(values)
    }

    /**
     * @param value A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("ysasdxykblchkxkn")
    public suspend fun attributes(`value`: List<Map<String, String>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param values A list of key-value pairs that match the attributes of the clients. The attributes are case-sensitive and must match the attributes provided by the clients during authentication.
     */
    @JvmName("pafjesrkcdqgqcls")
    public suspend fun attributes(vararg values: Map<String, String>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.attributes = mapped
    }

    /**
     * @param value A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("jbeobqgibkwacgep")
    public suspend fun clientids(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientids = mapped
    }

    /**
     * @param values A list of client IDs that match the clients. The client IDs are case-sensitive and must match the client IDs provided by the clients during connection.
     */
    @JvmName("beldbghppmcvanoo")
    public suspend fun clientids(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientids = mapped
    }

    /**
     * @param value A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("dsyjqljmwgoijwqe")
    public suspend fun usernames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    /**
     * @param values A list of usernames that match the clients. The usernames are case-sensitive and must match the usernames provided by the clients during authentication.
     */
    @JvmName("xlqwtihdihksuafu")
    public suspend fun usernames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.usernames = mapped
    }

    internal fun build(): PrincipalDefinitionArgs = PrincipalDefinitionArgs(
        attributes = attributes,
        clientids = clientids,
        usernames = usernames,
    )
}
